@@ -133,8 +133,9 @@ int  checkMtime(char * fname)
     stat(mfname,&buff);
     if(buff.st_mtime > tt) break;
   }
+
+  if(i<4) {unlink(fname); free(mfname);   return 1;}
   free(mfname);
-  if(i<4) {unlink(fname); return 1;}
   return 0;
 }
 
@@ -617,7 +618,7 @@ int HiggsLambdas(double Q, char * Higgs, double complex*lAA,double complex *lGG,
         double mX=pMass(Xp);
         double dffE=0,dfaE=0,dffC=0,dfaC=0;
         pdg=qNumbers(Xp, &spin2, &charge3, &cdim);
-        if((charge3 !=0 || cdim!=1) && mX>0.5)
+        if((charge3 !=0 || cdim!=1) && mX>0)
         {  
            double coeff[10]; 
            int k;
