@@ -38,7 +38,7 @@ static FILE * events_;
 static pthread_mutex_t wrt_key=PTHREAD_MUTEX_INITIALIZER;
 
 
-#define buffSize 100
+#define buffSize 1000
 
 static void writeEvent(double *x,  double  w)
 { 
@@ -59,7 +59,7 @@ static void writeEvent(double *x,  double  w)
    if(cb_pow)
    {  double sum=0;
       int err;
-      if(buffSize<cb_pow) cb_coeff=cb_coeff_; else cb_coeff=malloc(sizeof(REAL)*buffSize);
+      if(buffSize>cb_pow) cb_coeff=cb_coeff_; else cb_coeff=malloc(sizeof(REAL)*cb_pow);
       GG=sqrt(4*M_PI*alpha_2(qR));    
       sqme_int(Nsub,GG,pvectR,cb_coeff,&err);
          
