@@ -15,7 +15,7 @@
 #include "read_mdl.h"
 #include "model.h"
 #include "rootDir.h"
-#include "simpson.h"
+#include "1d_integration.h"
 #include "alphas2.h"
 #include "screen.h"
 #include "viewdir.h"
@@ -209,7 +209,6 @@ static void  writeSLHA(void)
    {  txtList all=NULL;
       double mass,width;
       char *name;
-      
       if( strcmp(ModelPrtcls[i].mass,"0")==0) continue;
       if( strcmp(ModelPrtcls[i].width,"0")==0) continue;
       name=ModelPrtcls[i].name;
